@@ -16,7 +16,7 @@
 #define CONFLUENCE_CHECKER_H
 
 #include <string>
-#include "aterm2.h"
+#include "mcrl2/aterm/aterm2.h"
 #include "mcrl2/data/rewriter.h"
 #include "mcrl2/data/detail/bdd_prover.h"
 #include "mcrl2/lps/disjointness_checker.h"
@@ -92,8 +92,8 @@
     Confluent tau-summands will be marked by renaming their tau-actions to ctau. The constructor
     Confluence_Checker::Confluence_Checker initializes the BDD based prover with the parameters a_rewrite_strategy,
     a_time_limit, a_path_eliminator, a_solver_type, a_apply_induction and a_lps. The parameter a_rewrite_strategy
-    specifies which rewrite strategy is used by the prover's rewriter. It can be set to either GS_REWR_INNER,
-    GS_REWR_INNERC, GS_REWR_JITTY or GS_REWR_JITTYC. The parameter a_time_limit specifies the maximum amount of time in
+    specifies which rewrite strategy is used by the prover's rewriter. It can be set to either 
+    GS_REWR_JITTY or GS_REWR_JITTYC. The parameter a_time_limit specifies the maximum amount of time in
     seconds to be spent by the prover on proving a single expression. If a_time_limit is set to 0, no time limit will be
     enforced. The parameter a_path_eliminator specifies whether or not path elimination is applied. When path
     elimination is applied, the prover uses an SMT solver to remove inconsistent paths from BDDs. The parameter
@@ -148,7 +148,7 @@ ATermAppl initAtermAppl(ATermAppl& f, ATermAppl v)
  **/
 inline action_label make_ctau_act_id()
 {
-  static ATermAppl ctau_act_id = initAtermAppl(ctau_act_id, mcrl2::core::detail::gsMakeActId(ATmakeAppl0(ATmakeAFun("ctau", 0, ATtrue)), ATmakeList0()));
+  static ATermAppl ctau_act_id = initAtermAppl(ctau_act_id, mcrl2::core::detail::gsMakeActId(ATmakeAppl0(ATmakeAFun("ctau", 0, true)), ATmakeList0()));
 
   assert(ctau_act_id);
 
