@@ -15,7 +15,7 @@
 #ifndef INVARIANT_ELIMINATOR_H
 #define INVARIANT_ELIMINATOR_H
 
-#include "aterm2.h"
+#include "mcrl2/aterm/aterm2.h"
 #include "mcrl2/data/rewriter.h"
 #include "mcrl2/data/detail/bdd_prover.h"
 #include "mcrl2/lps/specification.h"
@@ -29,7 +29,7 @@
 /// LPS. The constructor Invariant_Eliminator::Invariant_Eliminator initializes the BDD based prover with the parameters
 /// a_rewrite_strategy, a_time_limit, a_path_eliminator, a_solver_type, and the data specification of the LPS passed as
 /// parameter a_lps. The parameter a_rewrite_strategy specifies which rewrite strategy is used by the prover's rewriter.
-/// It can be set to either GS_REWR_INNER, GS_REWR_INNERC, GS_REWR_JITTY or GS_REWR_JITTYC. The parameter a_time_limit
+/// It can be set to either GS_REWR_JITTY or GS_REWR_JITTYC. The parameter a_time_limit
 /// specifies the maximum amount of time in seconds to be spent by the prover on proving a single expression. If
 /// a_time_limit is set to 0, no time limit will be enforced. The parameter a_path_eliminator specifies whether or not
 /// path elimination is applied. When path elimination is applied, the prover uses an SMT solver to remove inconsistent
