@@ -13,8 +13,8 @@
 #include <string>
 #include <algorithm>
 
-#include "mcrl2/core/messaging.h"
-#include "mcrl2/core/aterm_ext.h"
+#include "mcrl2/utilities/logger.h"
+#include "mcrl2/aterm/aterm_ext.h"
 #include "mcrl2/core/detail/struct_core.h"
 #include "mcrl2/data/detail/bdd_prover.h"
 #include "mcrl2/lps/confluence_checker.h"
@@ -100,17 +100,17 @@ data_expression get_subst_equation_from_assignments(
     }
     else if (v_variable == v_variable_1)
     {
-      v_variable_1 = data::replace_free_variables(v_variable_1,
+      data_expression expr = data::replace_free_variables(data_expression(v_variable_1),
                      data::make_map_substitution(a_substitutions_1));
-      v_result = sort_bool::and_(data_expression(v_result), equal_to(v_expression_1, data_expression(v_variable_1)));
+      v_result = sort_bool::and_(data_expression(v_result), equal_to(v_expression_1, expr));
       v_next_1 = true;
       v_next_2 = false;
     }
     else if (v_variable == v_variable_2)
     {
-      v_variable_2 = data::replace_free_variables(v_variable_2,
+      data_expression expr = data::replace_free_variables(data_expression(v_variable_2),
                      data::make_map_substitution(a_substitutions_2));
-      v_result = sort_bool::and_(data_expression(v_result), equal_to(data_expression(v_expression_2), data_expression(v_variable_2)));
+      v_result = sort_bool::and_(data_expression(v_result), equal_to(data_expression(v_expression_2), expr));
       v_next_1 = false;
       v_next_2 = true;
     }
@@ -224,6 +224,7 @@ data_expression get_confluence_condition(
       data::make_map_substitution(v_substitutions_2));
   const data_expression v_subst_condition_2 = data::replace_free_variables(v_condition_2,
       data::make_map_substitution(v_substitutions_1));
+
   const data_expression v_subst_equation = get_subst_equation_from_assignments(a_variables, v_assignments_1, v_assignments_2, v_substitutions_1, v_substitutions_2);
 
   const action_list v_actions =a_summand_2.multi_action().actions();
@@ -279,7 +280,7 @@ void Confluence_Checker::print_counter_example()
   if (f_counter_example)
   {
     const data_expression v_counter_example(f_bdd_prover.get_counter_example());
-    std::cerr << "  Counter example: " << pp(v_counter_example) << "\n";
+    std::cerr << "  Counter example: " << data::pp(v_counter_example) << "\n";
   }
 }
 
@@ -299,7 +300,7 @@ bool Confluence_Checker::check_summands(
 
   if (f_disjointness_checker.disjoint(a_summand_number_1, a_summand_number_2))
   {
-    gsMessage(":");
+    mCRL2log(info) << ":";
   }
   else
   {
@@ -307,33 +308,30 @@ bool Confluence_Checker::check_summands(
     f_bdd_prover.set_formula(v_condition);
     if (f_bdd_prover.is_tautology() == answer_yes)
     {
-      gsMessage("+");
+      mCRL2log(info) << "+";
     }
     else
     {
       if (f_generate_invariants)
       {
         const data_expression v_new_invariant(f_bdd_prover.get_bdd());
-        if (core::gsVerbose)
-        {
-          std::cerr << "\nChecking invariant: " << pp(v_new_invariant) << "\n";
-        }
+        mCRL2log(verbose) << "\nChecking invariant: " << data::pp(v_new_invariant) << "\n";
         if (f_invariant_checker.check_invariant(v_new_invariant))
         {
-          gsVerboseMsg("Invariant holds\n");
-          gsMessage("i");
+          mCRL2log(verbose) << "Invariant holds" << std::endl;
+          mCRL2log(info) << "i";
         }
         else
         {
-          gsVerboseMsg("Invariant doesn't hold\n");
+          mCRL2log(verbose) << "Invariant doesn't hold" << std::endl;
           v_is_confluent = false;
           if (f_check_all)
           {
-            gsMessage("-");
+            mCRL2log(info) << "-";
           }
           else
           {
-            gsMessage("Not confluent with summand %d.", a_summand_number_2);
+            mCRL2log(info) << "Not confluent with summand " << a_summand_number_2 << ".";
           }
           print_counter_example();
           save_dot_file(a_summand_number_1, a_summand_number_2);
@@ -344,11 +342,11 @@ bool Confluence_Checker::check_summands(
         v_is_confluent = false;
         if (f_check_all)
         {
-          gsMessage("-");
+          mCRL2log(info) << "-";
         }
         else
         {
-          gsMessage("Not confluent with summand %d.", a_summand_number_2);
+          mCRL2log(info) << "Not confluent with summand " << a_summand_number_2 << ".";
         }
         print_counter_example();
         save_dot_file(a_summand_number_1, a_summand_number_2);
@@ -382,7 +380,7 @@ action_summand Confluence_Checker::check_confluence_and_mark_summand(
   if (!a_summand_sum_variables.empty())
   {
     v_is_confluent = false;
-    gsMessage("Summand %d is not proven confluent because it contains a sum operator.",a_summand_number);
+    mCRL2log(info) << "Summand " << a_summand_number << " is not proven confluent because it contains a sum operator.";
   }
 
   for (action_summand_vector::const_iterator i=v_summands.begin();
@@ -394,7 +392,7 @@ action_summand Confluence_Checker::check_confluence_and_mark_summand(
     {
       if (f_intermediate[v_summand_number] > a_summand_number)
       {
-        gsMessage(".");
+        mCRL2log(info) << ".";
         v_summand_number++;
       }
       else
@@ -403,11 +401,11 @@ action_summand Confluence_Checker::check_confluence_and_mark_summand(
         {
           if (f_check_all)
           {
-            gsMessage("-");
+            mCRL2log(info) << "-";
           }
           else
           {
-            gsMessage("Not confluent with summand %d.", v_summand_number);
+            mCRL2log(info) << "Not confluent with summand " << v_summand_number << ".";
           }
           v_is_confluent = false;
         }
@@ -446,7 +444,7 @@ action_summand Confluence_Checker::check_confluence_and_mark_summand(
 
   if (v_is_confluent)
   {
-    gsMessage("Confluent with all summands.");
+    mCRL2log(info) << "Confluent with all summands.";
     a_is_marked = true;
     return action_summand(a_summand.summation_variables(),
                           a_summand.condition(),
@@ -513,9 +511,9 @@ specification Confluence_Checker::check_confluence_and_mark(const data_expressio
     {
       if (v_summand.is_tau())
       {
-        gsMessage("tau-summand %2d: ", v_summand_number);
+        mCRL2log(info) << "tau-summand " << v_summand_number << ": ";
         *i = check_confluence_and_mark_summand(a_invariant, v_summand, v_summand_number, v_is_marked);
-        gsMessage("\n");
+        mCRL2log(info) << std::endl;
       }
     }
     v_summand_number++;
