@@ -17,7 +17,7 @@
 #include "mcrl2/atermpp/indexed_set.h"
 #include "mcrl2/atermpp/table.h"
 #include "mcrl2/atermpp/vector.h"
-#include "mcrl2/core/messaging.h"
+#include "mcrl2/utilities/logger.h"
 #include "mcrl2/data/variable.h"
 #include "mcrl2/data/data_expression.h"
 #include "mcrl2/data/classic_enumerator.h"
@@ -184,7 +184,7 @@ pbes<> do_lazy_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
 {
   // Instantiate free variables in the system
   pbes_system::detail::instantiate_global_variables(pbes_spec);
-  core::gsVerboseMsg("Using lazy approach...\n");
+  mCRL2log(verbose) << "Using lazy approach..." << std::endl;
 
   propositional_variable_instantiation initial_state = pbes_spec.initial_state();
   atermpp::vector<pbes_equation> eqsys = pbes_spec.equations();
@@ -205,7 +205,7 @@ pbes<> do_lazy_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
 
   std::vector< core::identifier_string > names_order;
 
-  core::gsVerboseMsg("Retrieving PBES equations from equation system...\n");
+  mCRL2log(verbose) << "Retrieving PBES equations from equation system..." << std::endl;
   for (atermpp::vector<pbes_equation>::iterator eqi = eqsys.begin(); eqi != eqsys.end(); eqi++)
   {
     pbes_equations.put(eqi->variable().name(), pbes_equation_to_aterm(*eqi));
@@ -214,7 +214,7 @@ pbes<> do_lazy_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
 
   states_todo.insert(initial_state);
 
-  core::gsVerboseMsg("Computing BES...\n");
+  mCRL2log(verbose) << "Computing BES..." << std::endl;
   while (states_todo.size() != 0)
   {
     // Get the first element of the set
@@ -264,11 +264,11 @@ pbes<> do_lazy_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
 
     if (++nr_of_equations % 1000 == 0)
     {
-      core::gsVerboseMsg("At equation %d\n", nr_of_equations);
+      mCRL2log(verbose) << "At equation " <<  nr_of_equations << std::endl;
     }
   }
 
-  core::gsVerboseMsg("Sorting result...\n");
+  mCRL2log(verbose) << "Sorting result..." << std::endl;
   new_equation_system = sort_names(names_order, new_equation_system);
 
   // Rewrite initial state
@@ -283,11 +283,12 @@ pbes<> do_lazy_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
 /// \param pbes_spec A PBES
 /// \param rewrite A PBES rewriter
 template <typename PbesRewriter>
-pbes<> do_finite_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
+pbes<> do_finite_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite, const mcrl2::data::rewriter &data_rewriter)
+                   // Last argument is required for the enumerator, which needs a data rewriter.
 {
   // Instantiate free variables in the system
   pbes_system::detail::instantiate_global_variables(pbes_spec);
-  core::gsVerboseMsg("Using finite approach...\n");
+  mCRL2log(verbose) << "Using finite approach..." << std::endl;
 
   propositional_variable_instantiation initial_state = pbes_spec.initial_state();
   atermpp::vector<pbes_equation> eqsys = pbes_spec.equations();
@@ -303,7 +304,9 @@ pbes<> do_finite_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
   atermpp::table sort_enumerations(10,50);
 
   //Populate sort_enumerations with all enumerations for the finite sorts of the system
-  core::gsVerboseMsg("Enumerating finite data sorts...\n");
+  mCRL2log(verbose) << "Enumerating finite data sorts..." << std::endl;
+  typedef data::classic_enumerator<> enumerator_type;
+  enumerator_type enumerator(data, data_rewriter);
   for (atermpp::vector<pbes_equation>::const_iterator eq_i = eqsys.begin(); eq_i != eqsys.end(); eq_i++)
   {
     data::variable_list parameters = eq_i->variable().parameters();
@@ -315,16 +318,24 @@ pbes<> do_finite_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
         // if (check_finite(data.constructors(), current_sort))
         if (data.is_certainly_finite(current_sort))
         {
-          data::variable x("x", current_sort);
+          using namespace mcrl2::data;
+          variable x("x", current_sort);
 
-          // data::data_expression_list enumerations_from_sort = data::detail::enumerate_constructors (data.constructors(), current_sort);
-          sort_enumerations.put(current_sort, atermpp::convert< data::data_expression_list >(make_enumeration_sequence(x, data::make_simple_classic_enumerator< >(data, x))));
+          // data_expression_list enumerations_from_sort = detail::enumerate_constructors (data.constructors(), current_sort);
+          data_expression_list l;
+          for(typename enumerator_type::iterator i=enumerator.begin(std::vector<variable>(1,x),sort_bool::true_());
+                   i!=enumerator.end(); ++i)
+            {
+              const data_expression d=i->find(x)->second;
+              l=push_front(l,d);
+            }
+          sort_enumerations.put(current_sort, l);
         }
       }
     }
   }
 
-  core::gsVerboseMsg("Computing PBES without finite data sorts...\n");
+  mCRL2log(verbose) << "Computing PBES without finite data sorts..." << std::endl;
   for (atermpp::vector<pbes_equation>::iterator eq_i = eqsys.begin(); eq_i != eqsys.end(); eq_i++)
   {
     pbes_equation equation = *eq_i;
@@ -343,7 +354,7 @@ pbes<> do_finite_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
     instantiation_list.push_back(current_values);
 
     std::string propvar_name_string = propvar_name;
-    core::gsVerboseMsg("Creating all possible instantiations for propositional variable %s...\n", propvar_name_string.c_str());
+    mCRL2log(verbose) << "Creating all possible instantiations for propositional variable " <<  propvar_name_string << "..." << std::endl;
 
     for (data::variable_list::iterator p = propvar_parameters.begin(); p != propvar_parameters.end(); p++)
     {
@@ -377,7 +388,7 @@ pbes<> do_finite_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
       instantiation_list = intermediate_instantiation_list;
     }
 
-    core::gsVerboseMsg("Computing Boolean equations for each instantiation of propositional variable %s...\n", propvar_name_string.c_str());
+    mCRL2log(verbose) << "Computing Boolean equations for each instantiation of propositional variable " <<  propvar_name_string << "..." << std::endl;
 
     for (atermpp::vector< t_instantiations >::iterator inst_i = instantiation_list.begin(); inst_i != instantiation_list.end(); inst_i++)
     {
@@ -405,13 +416,13 @@ pbes<> do_finite_algorithm(pbes<> pbes_spec, PbesRewriter& rewrite)
 
       if (++nr_of_equations % 1000 == 0)
       {
-        core::gsVerboseMsg("At Boolean equation %d\n", nr_of_equations);
+        mCRL2log(verbose) << "At Boolean equation " <<  nr_of_equations << "" << std::endl;
       }
 
     }
   }
 
-  core::gsVerboseMsg("Instantiation process finished.\nNumber of Boolean equations computed: %d\n", nr_of_equations);
+  mCRL2log(verbose) << "Instantiation process finished.\nNumber of Boolean equations computed: " <<  nr_of_equations << "" << std::endl;
 
   // rewrite initial state
   propositional_variable_instantiation new_initial_state = create_naive_propositional_variable_instantiation(initial_state, &sort_enumerations);
