@@ -18,8 +18,9 @@
 #include <iterator>
 #include <boost/test/minimal.hpp>
 #include <boost/algorithm/string.hpp>
-#include "mcrl2/core/text_utility.h"
+#include "mcrl2/utilities/text_utility.h"
 #include "mcrl2/lps/linearise.h"
+#include "mcrl2/lps/detail/test_input.h"
 #include "mcrl2/modal_formula/parse.h"
 #include "mcrl2/pbes/pbes.h"
 #include "mcrl2/pbes/lps2pbes.h"
@@ -45,46 +46,6 @@ using namespace mcrl2::pbes_system::detail;
 namespace fs = boost::filesystem;
 #endif
 
-const std::string ABP_SPECIFICATION =
-  "% This file contains the alternating bit protocol, as described in W.J.    \n"
-  "% Fokkink, J.F. Groote and M.A. Reniers, Modelling Reactive Systems.       \n"
-  "%                                                                          \n"
-  "% The only exception is that the domain D consists of two data elements to \n"
-  "% facilitate simulation.                                                   \n"
-  "                                                                           \n"
-  "sort                                                                       \n"
-  "  D     = struct d1 | d2;                                                  \n"
-  "  Error = struct e;                                                        \n"
-  "                                                                           \n"
-  "act                                                                        \n"
-  "  r1,s4: D;                                                                \n"
-  "  s2,r2,c2: D # Bool;                                                      \n"
-  "  s3,r3,c3: D # Bool;                                                      \n"
-  "  s3,r3,c3: Error;                                                         \n"
-  "  s5,r5,c5: Bool;                                                          \n"
-  "  s6,r6,c6: Bool;                                                          \n"
-  "  s6,r6,c6: Error;                                                         \n"
-  "  i;                                                                       \n"
-  "                                                                           \n"
-  "proc                                                                       \n"
-  "  S(b:Bool)     = sum d:D. r1(d).T(d,b);                                   \n"
-  "  T(d:D,b:Bool) = s2(d,b).(r6(b).S(!b)+(r6(!b)+r6(e)).T(d,b));             \n"
-  "                                                                           \n"
-  "  R(b:Bool)     = sum d:D. r3(d,b).s4(d).s5(b).R(!b)+                      \n"
-  "                  (sum d:D.r3(d,!b)+r3(e)).s5(!b).R(b);                    \n"
-  "                                                                           \n"
-  "  K             = sum d:D,b:Bool. r2(d,b).(i.s3(d,b)+i.s3(e)).K;           \n"
-  "                                                                           \n"
-  "  L             = sum b:Bool. r5(b).(i.s6(b)+i.s6(e)).L;                   \n"
-  "                                                                           \n"
-  "init                                                                       \n"
-  "  allow({r1,s4,c2,c3,c5,c6,i},                                             \n"
-  "    comm({r2|s2->c2, r3|s3->c3, r5|s5->c5, r6|s6->c6},                     \n"
-  "        S(true) || K || L || R(true)                                       \n"
-  "    )                                                                      \n"
-  "  );                                                                       \n"
-  ;
-
 const std::string TIMED_SPECIFICATION =
   "act a;\n"
   "proc P = a@1 . P;\n"
@@ -95,7 +56,7 @@ const std::string TRIVIAL_FORMULA  = "[true*]<true*>true";
 
 void test_trivial()
 {
-  specification spec    = linearise(ABP_SPECIFICATION);
+  specification spec    = linearise(lps::detail::ABP_SPECIFICATION());
   state_formula formula = state_formulas::parse_state_formula(TRIVIAL_FORMULA, spec);
   bool timed = false;
   pbes<> p = lps2pbes(spec, formula, timed);
@@ -110,10 +71,10 @@ void test_timed()
   bool timed = true;
   pbes<> p = lps2pbes(spec, formula, timed);
   BOOST_CHECK(p.is_well_typed());
-  data::data_specification::sorts_const_range user_def_sorts(p.data().user_defined_sorts());
+  const atermpp::vector<sort_expression> user_def_sorts(p.data().user_defined_sorts());
   BOOST_CHECK(std::find(user_def_sorts.begin(), user_def_sorts.end(), sort_real::real_()) == user_def_sorts.end());
 
-  data::data_specification::sorts_const_range sorts(p.data().sorts());
+  const atermpp::vector<sort_expression> sorts(p.data().sorts());
   BOOST_CHECK(std::find(sorts.begin(), sorts.end(), sort_real::real_()) != sorts.end());
   core::garbage_collect();
 }
@@ -230,23 +191,23 @@ void test_lps2pbes2()
   bool timed = false;
 
   FORMULA = "mu X. !!X";
-  p = lps2pbes(ABP_SPECIFICATION, FORMULA, timed);
+  p = lps2pbes(lps::detail::ABP_SPECIFICATION(), FORMULA, timed);
   BOOST_CHECK(p.is_well_typed());
 
   FORMULA = "nu X. ([true]X && <true>true)";
-  p = lps2pbes(ABP_SPECIFICATION, FORMULA, timed);
+  p = lps2pbes(lps::detail::ABP_SPECIFICATION(), FORMULA, timed);
   BOOST_CHECK(p.is_well_typed());
 
   FORMULA = "nu X. ([true]X && forall d:D. [r1(d)] mu Y. (<true>Y || <s4(d)>true))";
-  p = lps2pbes(ABP_SPECIFICATION, FORMULA, timed);
+  p = lps2pbes(lps::detail::ABP_SPECIFICATION(), FORMULA, timed);
   BOOST_CHECK(p.is_well_typed());
 
   FORMULA = "forall d:D. nu X. (([!r1(d)]X && [s4(d)]false))";
-  p = lps2pbes(ABP_SPECIFICATION, FORMULA, timed);
+  p = lps2pbes(lps::detail::ABP_SPECIFICATION(), FORMULA, timed);
   BOOST_CHECK(p.is_well_typed());
 
   FORMULA = "nu X. ([true]X && forall d:D. [r1(d)]nu Y. ([!r1(d) && !s4(d)]Y && [r1(d)]false))";
-  p = lps2pbes(ABP_SPECIFICATION, FORMULA, timed);
+  p = lps2pbes(lps::detail::ABP_SPECIFICATION(), FORMULA, timed);
   BOOST_CHECK(p.is_well_typed());
   core::garbage_collect();
 }
@@ -300,7 +261,7 @@ void test_directory(int argc, char** argv)
       {
         std::string timed_result_file   = filename.substr(0, filename.find_last_of('.') + 1) + "expected_timed_result";
         std::string untimed_result_file = filename.substr(0, filename.find_last_of('.') + 1) + "expected_untimed_result";
-        std::string formula = mcrl2::core::read_text(filename);
+        std::string formula = mcrl2::utilities::read_text(filename);
         if (fs::exists(timed_result_file))
         {
           try
