@@ -25,6 +25,8 @@
 #include "mcrl2/core/detail/print_utility.h"
 #include "mcrl2/data/utility.h"
 #include "mcrl2/lps/linearise.h"
+#include "mcrl2/lps/detail/test_input.h"
+#include "mcrl2/pbes/is_bes.h"
 #include "mcrl2/pbes/pbes.h"
 #include "mcrl2/pbes/parse.h"
 #include "mcrl2/pbes/pbes_translate.h"
@@ -69,46 +71,6 @@ const std::string SPECIFICATION =
   "                                         \n"
   "init P(0);                               \n";
 
-const std::string ABP_SPECIFICATION =
-  "% This file contains the alternating bit protocol, as described in W.J.    \n"
-  "% Fokkink, J.F. Groote and M.A. Reniers, Modelling Reactive Systems.       \n"
-  "%                                                                          \n"
-  "% The only exception is that the domain D consists of two data elements to \n"
-  "% facilitate simulation.                                                   \n"
-  "                                                                           \n"
-  "sort                                                                       \n"
-  "  D     = struct d1 | d2;                                                  \n"
-  "  Error = struct e;                                                        \n"
-  "                                                                           \n"
-  "act                                                                        \n"
-  "  r1,s4: D;                                                                \n"
-  "  s2,r2,c2: D # Bool;                                                      \n"
-  "  s3,r3,c3: D # Bool;                                                      \n"
-  "  s3,r3,c3: Error;                                                         \n"
-  "  s5,r5,c5: Bool;                                                          \n"
-  "  s6,r6,c6: Bool;                                                          \n"
-  "  s6,r6,c6: Error;                                                         \n"
-  "  i;                                                                       \n"
-  "                                                                           \n"
-  "proc                                                                       \n"
-  "  S(b:Bool)     = sum d:D. r1(d).T(d,b);                                   \n"
-  "  T(d:D,b:Bool) = s2(d,b).(r6(b).S(!b)+(r6(!b)+r6(e)).T(d,b));             \n"
-  "                                                                           \n"
-  "  R(b:Bool)     = sum d:D. r3(d,b).s4(d).s5(b).R(!b)+                      \n"
-  "                  (sum d:D.r3(d,!b)+r3(e)).s5(!b).R(b);                    \n"
-  "                                                                           \n"
-  "  K             = sum d:D,b:Bool. r2(d,b).(i.s3(d,b)+i.s3(e)).K;           \n"
-  "                                                                           \n"
-  "  L             = sum b:Bool. r5(b).(i.s6(b)+i.s6(e)).L;                   \n"
-  "                                                                           \n"
-  "init                                                                       \n"
-  "  allow({r1,s4,c2,c3,c5,c6,i},                                             \n"
-  "    comm({r2|s2->c2, r3|s3->c3, r5|s5->c5, r6|s6->c6},                     \n"
-  "        S(true) || K || L || R(true)                                       \n"
-  "    )                                                                      \n"
-  "  );                                                                       \n"
-  ;
-
 const std::string TRIVIAL_FORMULA  = "[true*]<true*>true";
 
 const std::string MPSU_SPECIFICATION =
@@ -178,8 +140,8 @@ void test_pbes()
   pbes<> p = lps2pbes(spec, formula, timed);
   pbes_expression e = p.equations().front().formula();
 
-  BOOST_CHECK(!p.is_bes());
-  BOOST_CHECK(!e.is_bes());
+  BOOST_CHECK(!is_bes(p));
+  BOOST_CHECK(!is_bes(e));
 
   try
   {
@@ -303,7 +265,7 @@ void test_pbes_expression()
 
 void test_trivial()
 {
-  specification spec    = linearise(ABP_SPECIFICATION);
+  specification spec    = linearise(lps::detail::ABP_SPECIFICATION());
   state_formula formula = state_formulas::parse_state_formula(TRIVIAL_FORMULA, spec);
   bool timed = false;
   pbes<> p = lps2pbes(spec, formula, timed);
@@ -327,7 +289,7 @@ void test_instantiate_global_variables()
   std::cout << "<before>" << mcrl2::core::pp(p) << std::endl;
   std::cout << "<lps>" << lps::pp(spec) << std::endl;
   pbes_system::detail::instantiate_global_variables(p);
-  std::cout << "<after>" << pp(p) << std::endl;
+  std::cout << "<after>" << pbes_system::pp(p) << std::endl;
   core::garbage_collect();
 }
 
@@ -335,7 +297,7 @@ void test_find_sort_expressions()
 {
   using data::sort_expression;
 
-  specification spec    = linearise(ABP_SPECIFICATION);
+  specification spec    = linearise(lps::detail::ABP_SPECIFICATION());
   state_formula formula = state_formulas::parse_state_formula(TRIVIAL_FORMULA, spec);
   bool timed = false;
   pbes<> p = lps2pbes(spec, formula, timed);
@@ -376,7 +338,7 @@ void test_is_bes()
     "init X;           \n"
     ;
   pbes<> p = txt2pbes(text);
-  BOOST_CHECK(p.is_bes());
+  BOOST_CHECK(is_bes(p));
 }
 
 int test_main(int argc, char** argv)
