@@ -1,6 +1,6 @@
 #include <boost/test/minimal.hpp>
 #include <sstream>
-#include <aterm2.h>
+#include "mcrl2/aterm/aterm2.h"
 #include "mcrl2/atermpp/aterm_init.h"
 #include "mcrl2/trace/trace.h"
 
