@@ -11,7 +11,7 @@
 #include "wx.hpp" // precompiled headers
 
 #include "wx/wx.h"
-#include "mcrl2/core/messaging.h"
+#include "mcrl2/utilities/logger.h"
 #include "mcrl2gen/mcrl2gen.h"
 #include "grape_frame.h"
 
@@ -95,7 +95,7 @@ extern "C" int WINAPI WinMain(HINSTANCE hInstance,
 {
 
   MCRL2_ATERMPP_INIT(0, lpCmdLine);
-  gsSetVerboseMsg();
+  mcrl2_logger::set_reporting_level(log_verbose);
   return wxEntry(hInstance, hPrevInstance, lpCmdLine, nCmdShow);
 }
 #endif
