@@ -21,13 +21,13 @@
 #endif
 
 #include <sstream>
-#include <aterm2.h>
+#include "mcrl2/aterm/aterm2.h"
 #include "simbasegui.h"
 #include "xsimtracedll.h"
 #include "mcrl2/core/print.h"
-#include "mcrl2/lps/nextstate.h"
-#include "mcrl2/core/messaging.h"
-#include "mcrl2/core/aterm_ext.h"
+// #include "mcrl2/lps/nextstate.h"
+#include "mcrl2/utilities/logger.h"
+#include "mcrl2/aterm/aterm_ext.h"
 
 using namespace std;
 using namespace mcrl2::core;
