@@ -19,7 +19,7 @@
 
 #include <wx/wx.h>
 #include <wx/listctrl.h>
-#include <aterm2.h>
+#include "mcrl2/aterm/aterm2.h"
 #include "simbase.h"
 
 //----------------------------------------------------------------------------
