@@ -43,6 +43,8 @@
 
 #include "wx/mimetype.h"
 
+#include "icons/mcrl2-gui.xpm"
+
 // IDs for the controls and the menu commands
 enum
 {
@@ -80,6 +82,8 @@ class MainFrame: public wxFrame
     {
       m_pidLast = 0;
 
+      SetIcon(wxIcon(mcrl2_gui_xpm));
+
 #ifdef __WXMAC__
       // required since ABOUT is not the default id of the about menu
       wxApp::s_macAboutMenuItemId = wxID_ABOUT;
